# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class DashboardFieldRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'display_name': 'str',
        'id': 'int',
        'is_grouped': 'bool',
        'is_hidden': 'bool',
        'is_pinned': 'bool',
        'order': 'int',
        'width': 'int'
    }

    attribute_map = {
        'display_name': 'display_name',
        'id': 'id',
        'is_grouped': 'is_grouped',
        'is_hidden': 'is_hidden',
        'is_pinned': 'is_pinned',
        'order': 'order',
        'width': 'width'
    }

    def __init__(self, display_name=None, id=None, is_grouped=None, is_hidden=None, is_pinned=None, order=None, width=None, local_vars_configuration=None):  # noqa: E501
        """DashboardFieldRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._display_name = None
        self._id = None
        self._is_grouped = None
        self._is_hidden = None
        self._is_pinned = None
        self._order = None
        self._width = None
        self.discriminator = None

        if display_name is not None:
            self.display_name = display_name
        self.id = id
        self.is_grouped = is_grouped
        self.is_hidden = is_hidden
        self.is_pinned = is_pinned
        self.order = order
        self.width = width

    @property
    def display_name(self):
        """Gets the display_name of this DashboardFieldRequest.  # noqa: E501


        :return: The display_name of this DashboardFieldRequest.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this DashboardFieldRequest.


        :param display_name: The display_name of this DashboardFieldRequest.  # noqa: E501
        :type display_name: str
        """
        if (self.local_vars_configuration.client_side_validation and
                display_name is not None and len(display_name) > 255):
            raise ValueError("Invalid value for `display_name`, length must be less than or equal to `255`")  # noqa: E501

        self._display_name = display_name

    @property
    def id(self):
        """Gets the id of this DashboardFieldRequest.  # noqa: E501


        :return: The id of this DashboardFieldRequest.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DashboardFieldRequest.


        :param id: The id of this DashboardFieldRequest.  # noqa: E501
        :type id: int
        """
        if self.local_vars_configuration.client_side_validation and id is None:  # noqa: E501
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def is_grouped(self):
        """Gets the is_grouped of this DashboardFieldRequest.  # noqa: E501


        :return: The is_grouped of this DashboardFieldRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_grouped

    @is_grouped.setter
    def is_grouped(self, is_grouped):
        """Sets the is_grouped of this DashboardFieldRequest.


        :param is_grouped: The is_grouped of this DashboardFieldRequest.  # noqa: E501
        :type is_grouped: bool
        """

        self._is_grouped = is_grouped

    @property
    def is_hidden(self):
        """Gets the is_hidden of this DashboardFieldRequest.  # noqa: E501


        :return: The is_hidden of this DashboardFieldRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_hidden

    @is_hidden.setter
    def is_hidden(self, is_hidden):
        """Sets the is_hidden of this DashboardFieldRequest.


        :param is_hidden: The is_hidden of this DashboardFieldRequest.  # noqa: E501
        :type is_hidden: bool
        """

        self._is_hidden = is_hidden

    @property
    def is_pinned(self):
        """Gets the is_pinned of this DashboardFieldRequest.  # noqa: E501


        :return: The is_pinned of this DashboardFieldRequest.  # noqa: E501
        :rtype: bool
        """
        return self._is_pinned

    @is_pinned.setter
    def is_pinned(self, is_pinned):
        """Sets the is_pinned of this DashboardFieldRequest.


        :param is_pinned: The is_pinned of this DashboardFieldRequest.  # noqa: E501
        :type is_pinned: bool
        """

        self._is_pinned = is_pinned

    @property
    def order(self):
        """Gets the order of this DashboardFieldRequest.  # noqa: E501


        :return: The order of this DashboardFieldRequest.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this DashboardFieldRequest.


        :param order: The order of this DashboardFieldRequest.  # noqa: E501
        :type order: int
        """
        if (self.local_vars_configuration.client_side_validation and
                order is not None and order < 1):  # noqa: E501
            raise ValueError("Invalid value for `order`, must be a value greater than or equal to `1`")  # noqa: E501

        self._order = order

    @property
    def width(self):
        """Gets the width of this DashboardFieldRequest.  # noqa: E501


        :return: The width of this DashboardFieldRequest.  # noqa: E501
        :rtype: int
        """
        return self._width

    @width.setter
    def width(self, width):
        """Sets the width of this DashboardFieldRequest.


        :param width: The width of this DashboardFieldRequest.  # noqa: E501
        :type width: int
        """
        if (self.local_vars_configuration.client_side_validation and
                width is not None and width < 1):  # noqa: E501
            raise ValueError("Invalid value for `width`, must be a value greater than or equal to `1`")  # noqa: E501

        self._width = width

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DashboardFieldRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DashboardFieldRequest):
            return True

        return self.to_dict() != other.to_dict()
