# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'max_replica': 'int',
        'min_replica': 'int',
        'revision': 'OrmModelServiceRolloutRevisionReference',
        'running': 'bool'
    }

    attribute_map = {
        'max_replica': 'max_replica',
        'min_replica': 'min_replica',
        'revision': 'revision',
        'running': 'running'
    }

    def __init__(self, max_replica=None, min_replica=None, revision=None, running=None, local_vars_configuration=None):  # noqa: E501
        """OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._max_replica = None
        self._min_replica = None
        self._revision = None
        self._running = None
        self.discriminator = None

        if max_replica is not None:
            self.max_replica = max_replica
        if min_replica is not None:
            self.min_replica = min_replica
        self.revision = revision
        if running is not None:
            self.running = running

    @property
    def max_replica(self):
        """Gets the max_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501


        :return: The max_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :rtype: int
        """
        return self._max_replica

    @max_replica.setter
    def max_replica(self, max_replica):
        """Sets the max_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.


        :param max_replica: The max_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :type max_replica: int
        """

        self._max_replica = max_replica

    @property
    def min_replica(self):
        """Gets the min_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501


        :return: The min_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :rtype: int
        """
        return self._min_replica

    @min_replica.setter
    def min_replica(self, min_replica):
        """Sets the min_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.


        :param min_replica: The min_replica of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :type min_replica: int
        """

        self._min_replica = min_replica

    @property
    def revision(self):
        """Gets the revision of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501


        :return: The revision of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :rtype: OrmModelServiceRolloutRevisionReference
        """
        return self._revision

    @revision.setter
    def revision(self, revision):
        """Sets the revision of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.


        :param revision: The revision of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :type revision: OrmModelServiceRolloutRevisionReference
        """
        if self.local_vars_configuration.client_side_validation and revision is None:  # noqa: E501
            raise ValueError("Invalid value for `revision`, must not be `None`")  # noqa: E501

        self._revision = revision

    @property
    def running(self):
        """Gets the running of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501


        :return: The running of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :rtype: bool
        """
        return self._running

    @running.setter
    def running(self, running):
        """Sets the running of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.


        :param running: The running of this OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget.  # noqa: E501
        :type running: bool
        """

        self._running = running

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmModelServiceRolloutStepUpdateRevisionsRevisionTarget):
            return True

        return self.to_dict() != other.to_dict()
